<?php

namespace Asadi\Semester\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Asadi\Semester\Interfaces\SemesterRepositoryInterface;
use Asadi\Semester\Repositories\Presenter\SemesterItemTransformer;

/**
 * Pubic API controller class.
 */
class SemesterPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Asadi\Semester\Interfaces\SemesterRepositoryInterface $semester
     *
     * @return type
     */
    public function __construct(SemesterRepositoryInterface $semester)
    {
        $this->repository = $semester;
        parent::__construct();
    }

    /**
     * Show semester's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $semesters = $this->repository
            ->setPresenter('\\Asadi\\Semester\\Repositories\\Presenter\\SemesterListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $semesters['code'] = 2000;
        return response()->json($semesters)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show semester.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $semester = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($semester)) {
            $semester         = $this->itemPresenter($module, new SemesterItemTransformer);
            $semester['code'] = 2001;
            return response()->json($semester)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
