<?php

namespace Asadi\Semester\Http\Controllers;
use Litepie\Semester\Http\Requests\SemesterRequest;
use Litepie\Semester\Models\Semester;

trait SemesterWorkflow {
	
    /**
     * Workflow controller function for semester.
     *
     * @param Model   $semester
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(SemesterRequest $request, Semester $semester, $step)
    {

        try {

            $semester->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('semester::semester.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/semester/semester/' . $semester->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/semester/semester/' . $semester->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for semester.
     *
     * @param Model   $semester
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Semester $semester, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $semester->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('semester::semester.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('semester::admin.semester.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('semester::admin.semester.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('semester::admin.semester.message', $data)->render();

        }

    }
}