<?php

namespace Asadi\Semester\Policies;

use App\User;
use Asadi\Semester\Models\Semester;

class SemesterPolicy
{

    /**
     * Determine if the given user can view the semester.
     *
     * @param User $user
     * @param Semester $semester
     *
     * @return bool
     */
    public function view(User $user, Semester $semester)
    {
        if ($user->canDo('semester.semester.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $semester->user_id;
    }

    /**
     * Determine if the given user can create a semester.
     *
     * @param User $user
     * @param Semester $semester
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('semester.semester.create');
    }

    /**
     * Determine if the given user can update the given semester.
     *
     * @param User $user
     * @param Semester $semester
     *
     * @return bool
     */
    public function update(User $user, Semester $semester)
    {
        if ($user->canDo('semester.semester.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $semester->user_id;
    }

    /**
     * Determine if the given user can delete the given semester.
     *
     * @param User $user
     * @param Semester $semester
     *
     * @return bool
     */
    public function destroy(User $user, Semester $semester)
    {
        if ($user->canDo('semester.semester.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $semester->user_id;
    }

    /**
     * Determine if the given user can verify the given semester.
     *
     * @param User $user
     * @param Semester $semester
     *
     * @return bool
     */
    public function verify(User $user, Semester $semester)
    {
        if ($user->canDo('semester.semester.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('semester.semester.verify') 
        && $user->is('manager')
        && $semester->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given semester.
     *
     * @param User $user
     * @param Semester $semester
     *
     * @return bool
     */
    public function approve(User $user, Semester $semester)
    {
        if ($user->canDo('semester.semester.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
