<?php

namespace Asadi\Semester\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Asadi\Semester\Models\Semester;

class SemesterAction
{
    /**
     * Perform the complete action.
     *
     * @param Semester $semester
     *
     * @return Semester
     */
    public function complete(Semester $semester)
    {
        try {
            $semester->status = 'complete';
            return $semester->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Semester $semester
     *
     * @return Semester
     */public function verify(Semester $semester)
    {
        try {
            $semester->status = 'verify';
            return $semester->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Semester $semester
     *
     * @return Semester
     */public function approve(Semester $semester)
    {
        try {
            $semester->status = 'approve';
            return $semester->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Semester $semester
     *
     * @return Semester
     */public function publish(Semester $semester)
    {
        try {
            $semester->status = 'publish';
            return $semester->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Semester $semester
     *
     * @return Semester
     */
    public function archive(Semester $semester)
    {
        try {
            $semester->status = 'archive';
            return $semester->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Semester $semester
     *
     * @return Semester
     */
    public function unpublish(Semester $semester)
    {
        try {
            $semester->status = 'unpublish';
            return $semester->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
