<?php

namespace Asadi\Semester\Workflow;

use Asadi\Semester\Models\Semester;
use Validator;

class SemesterValidator
{

    /**
     * Determine if the given semester is valid for complete status.
     *
     * @param Semester $semester
     *
     * @return bool / Validator
     */
    public function complete(Semester $semester)
    {
        return Validator::make($semester->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given semester is valid for verify status.
     *
     * @param Semester $semester
     *
     * @return bool / Validator
     */
    public function verify(Semester $semester)
    {
        return Validator::make($semester->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given semester is valid for approve status.
     *
     * @param Semester $semester
     *
     * @return bool / Validator
     */
    public function approve(Semester $semester)
    {
        return Validator::make($semester->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given semester is valid for publish status.
     *
     * @param Semester $semester
     *
     * @return bool / Validator
     */
    public function publish(Semester $semester)
    {
        return Validator::make($semester->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given semester is valid for archive status.
     *
     * @param Semester $semester
     *
     * @return bool / Validator
     */
    public function archive(Semester $semester)
    {
        return Validator::make($semester->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given semester is valid for unpublish status.
     *
     * @param Semester $semester
     *
     * @return bool / Validator
     */
    public function unpublish(Semester $semester)
    {
        return Validator::make($semester->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
